pub struct MeteoraDammV2SwapEvent {Show 20 fields
pub metadata: EventMetadata,
pub pool: Pubkey,
pub amount_in: u64,
pub output_amount: u64,
pub trade_direction: u8,
pub has_referral: bool,
pub minimum_amount_out: u64,
pub next_sqrt_price: u128,
pub lp_fee: u64,
pub protocol_fee: u64,
pub partner_fee: u64,
pub referral_fee: u64,
pub actual_amount_in: u64,
pub current_timestamp: u64,
pub token_a_vault: Pubkey,
pub token_b_vault: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub token_a_program: Pubkey,
pub token_b_program: Pubkey,
}Expand description
Meteora DAMM V2 Swap Event
Fields
metadata: EventMetadatapool: Pubkeyamount_in: u64output_amount: u64trade_direction: u8has_referral: boolminimum_amount_out: u64next_sqrt_price: u128lp_fee: u64protocol_fee: u64partner_fee: u64referral_fee: u64actual_amount_in: u64current_timestamp: u64token_a_vault: Pubkeytoken_b_vault: Pubkeytoken_a_mint: Pubkeytoken_b_mint: Pubkeytoken_a_program: Pubkeytoken_b_program: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for MeteoraDammV2SwapEvent
impl BorshDeserialize for MeteoraDammV2SwapEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MeteoraDammV2SwapEvent
impl Clone for MeteoraDammV2SwapEvent
Sourcefn clone(&self) -> MeteoraDammV2SwapEvent
fn clone(&self) -> MeteoraDammV2SwapEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeteoraDammV2SwapEvent
impl Debug for MeteoraDammV2SwapEvent
Sourceimpl Default for MeteoraDammV2SwapEvent
impl Default for MeteoraDammV2SwapEvent
Sourcefn default() -> MeteoraDammV2SwapEvent
fn default() -> MeteoraDammV2SwapEvent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for MeteoraDammV2SwapEvent
impl<'de> Deserialize<'de> for MeteoraDammV2SwapEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more