pub struct MeteoraDlmmClaimFeeEvent {
pub metadata: EventMetadata,
pub pool: Pubkey,
pub position: Pubkey,
pub owner: Pubkey,
pub fee_x: u64,
pub fee_y: u64,
}Expand description
Meteora DLMM Claim Fee Event
Fields
metadata: EventMetadatapool: Pubkeyposition: Pubkeyowner: Pubkeyfee_x: u64fee_y: u64Trait Implementations
Sourceimpl BorshDeserialize for MeteoraDlmmClaimFeeEvent
impl BorshDeserialize for MeteoraDlmmClaimFeeEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MeteoraDlmmClaimFeeEvent
impl Clone for MeteoraDlmmClaimFeeEvent
Sourcefn clone(&self) -> MeteoraDlmmClaimFeeEvent
fn clone(&self) -> MeteoraDlmmClaimFeeEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeteoraDlmmClaimFeeEvent
impl Debug for MeteoraDlmmClaimFeeEvent
Sourceimpl<'de> Deserialize<'de> for MeteoraDlmmClaimFeeEvent
impl<'de> Deserialize<'de> for MeteoraDlmmClaimFeeEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more