pub struct OrcaWhirlpoolLiquidityDecreasedEvent {
pub metadata: EventMetadata,
pub whirlpool: Pubkey,
pub liquidity: u128,
pub token_a_amount: u64,
pub token_b_amount: u64,
pub position: Pubkey,
pub tick_lower_index: i32,
pub tick_upper_index: i32,
pub token_a_transfer_fee: u64,
pub token_b_transfer_fee: u64,
}Expand description
Orca Whirlpool Liquidity Decreased Event
Fields
metadata: EventMetadatawhirlpool: Pubkeyliquidity: u128token_a_amount: u64token_b_amount: u64position: Pubkeytick_lower_index: i32tick_upper_index: i32token_a_transfer_fee: u64token_b_transfer_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for OrcaWhirlpoolLiquidityDecreasedEvent
impl BorshDeserialize for OrcaWhirlpoolLiquidityDecreasedEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OrcaWhirlpoolLiquidityDecreasedEvent
impl Clone for OrcaWhirlpoolLiquidityDecreasedEvent
Sourcefn clone(&self) -> OrcaWhirlpoolLiquidityDecreasedEvent
fn clone(&self) -> OrcaWhirlpoolLiquidityDecreasedEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for OrcaWhirlpoolLiquidityDecreasedEvent
impl<'de> Deserialize<'de> for OrcaWhirlpoolLiquidityDecreasedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more