pub struct PumpFeesShareholder {
pub address: Pubkey,
pub share_bps: u16,
}Expand description
IDL Shareholder
Fields
address: PubkeyTrait Implementations
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourcefn clone(&self) -> PumpFeesShareholder
fn clone(&self) -> PumpFeesShareholder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn default() -> PumpFeesShareholder
fn default() -> PumpFeesShareholder
Returns the “default value” for a type. Read more
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourcefn eq(&self, other: &PumpFeesShareholder) -> bool
fn eq(&self, other: &PumpFeesShareholder) -> bool
Tests for
self and other values to be equal, and is used by ==.Auto Trait Implementations