pub struct PumpFunCreateV2TokenEvent {Show 28 fields
pub metadata: EventMetadata,
pub name: String,
pub symbol: String,
pub uri: String,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub user: Pubkey,
pub creator: Pubkey,
pub timestamp: i64,
pub virtual_token_reserves: u64,
pub virtual_sol_reserves: u64,
pub real_token_reserves: u64,
pub token_total_supply: u64,
pub token_program: Pubkey,
pub is_mayhem_mode: bool,
pub is_cashback_enabled: bool,
pub mint_authority: Pubkey,
pub associated_bonding_curve: Pubkey,
pub global: Pubkey,
pub system_program: Pubkey,
pub associated_token_program: Pubkey,
pub mayhem_program_id: Pubkey,
pub global_params: Pubkey,
pub sol_vault: Pubkey,
pub mayhem_state: Pubkey,
pub mayhem_token_vault: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
PumpFun Create V2 Token Event (SPL-22 / Mayhem Mode) 与 solana-streamer 对齐;指令解析时从 accounts 0..15 填充。
Fields
metadata: EventMetadataname: Stringsymbol: Stringuri: Stringmint: Pubkeybonding_curve: Pubkeyuser: Pubkeycreator: Pubkeytimestamp: i64virtual_token_reserves: u64virtual_sol_reserves: u64real_token_reserves: u64token_total_supply: u64token_program: Pubkeyis_mayhem_mode: boolis_cashback_enabled: boolassociated_bonding_curve: Pubkeyglobal: Pubkeysystem_program: Pubkeyassociated_token_program: Pubkeymayhem_program_id: Pubkeyglobal_params: Pubkeysol_vault: Pubkeymayhem_state: Pubkeymayhem_token_vault: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for PumpFunCreateV2TokenEvent
impl BorshDeserialize for PumpFunCreateV2TokenEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for PumpFunCreateV2TokenEvent
impl Clone for PumpFunCreateV2TokenEvent
Sourcefn clone(&self) -> PumpFunCreateV2TokenEvent
fn clone(&self) -> PumpFunCreateV2TokenEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PumpFunCreateV2TokenEvent
impl Debug for PumpFunCreateV2TokenEvent
Sourceimpl Default for PumpFunCreateV2TokenEvent
impl Default for PumpFunCreateV2TokenEvent
Sourcefn default() -> PumpFunCreateV2TokenEvent
fn default() -> PumpFunCreateV2TokenEvent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PumpFunCreateV2TokenEvent
impl<'de> Deserialize<'de> for PumpFunCreateV2TokenEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more