pub struct PumpSwapBuyEvent {Show 50 fields
pub metadata: EventMetadata,
pub timestamp: i64,
pub base_amount_out: u64,
pub max_quote_amount_in: u64,
pub user_base_token_reserves: u64,
pub user_quote_token_reserves: u64,
pub pool_base_token_reserves: u64,
pub pool_quote_token_reserves: u64,
pub quote_amount_in: u64,
pub lp_fee_basis_points: u64,
pub lp_fee: u64,
pub protocol_fee_basis_points: u64,
pub protocol_fee: u64,
pub quote_amount_in_with_lp_fee: u64,
pub user_quote_amount_in: u64,
pub pool: Pubkey,
pub user: Pubkey,
pub user_base_token_account: Pubkey,
pub user_quote_token_account: Pubkey,
pub protocol_fee_recipient: Pubkey,
pub protocol_fee_recipient_token_account: Pubkey,
pub coin_creator: Pubkey,
pub coin_creator_fee_basis_points: u64,
pub coin_creator_fee: u64,
pub track_volume: bool,
pub total_unclaimed_tokens: u64,
pub total_claimed_tokens: u64,
pub current_sol_volume: u64,
pub last_update_timestamp: i64,
pub min_base_amount_out: u64,
pub ix_name: String,
pub cashback_fee_basis_points: u64,
pub cashback: u64,
pub buyback_fee_basis_points: u64,
pub buyback_fee: u64,
pub virtual_quote_reserves: i128,
pub can_boost: bool,
pub base_supply: u64,
pub is_pump_pool: bool,
pub base_mint: Pubkey,
pub quote_mint: Pubkey,
pub pool_base_token_account: Pubkey,
pub pool_quote_token_account: Pubkey,
pub coin_creator_vault_ata: Pubkey,
pub coin_creator_vault_authority: Pubkey,
pub base_token_program: Pubkey,
pub quote_token_program: Pubkey,
pub pool_v2: Pubkey,
pub fee_recipient: Pubkey,
pub fee_recipient_quote_token_account: Pubkey,
}Expand description
PumpSwap Buy Event
Fields
metadata: EventMetadatatimestamp: i64base_amount_out: u64max_quote_amount_in: u64user_base_token_reserves: u64user_quote_token_reserves: u64pool_base_token_reserves: u64pool_quote_token_reserves: u64quote_amount_in: u64lp_fee_basis_points: u64lp_fee: u64protocol_fee_basis_points: u64protocol_fee: u64quote_amount_in_with_lp_fee: u64user_quote_amount_in: u64pool: Pubkeyuser: Pubkeyuser_base_token_account: Pubkeyuser_quote_token_account: Pubkeyprotocol_fee_recipient: Pubkeyprotocol_fee_recipient_token_account: Pubkeycoin_creator: Pubkeycoin_creator_fee_basis_points: u64coin_creator_fee: u64track_volume: booltotal_unclaimed_tokens: u64total_claimed_tokens: u64current_sol_volume: u64last_update_timestamp: i64min_base_amount_out: u64Minimum base token amount expected (new field from IDL update)
ix_name: StringInstruction name (new field from IDL update)
cashback_fee_basis_points: u64Cashback fee basis points (PUMP_CASHBACK_README)
cashback: u64Cashback amount (PUMP_CASHBACK_README)
buyback_fee_basis_points: u64buyback_fee: u64virtual_quote_reserves: i128Signed virtual quote reserves appended by the PumpSwap boost upgrade.
can_boost: boolbase_supply: u64is_pump_pool: boolbase_mint: Pubkeyquote_mint: Pubkeypool_base_token_account: Pubkeypool_quote_token_account: Pubkeycoin_creator_vault_ata: Pubkeybase_token_program: Pubkeyquote_token_program: Pubkeypool_v2: Pubkeyfee_recipient: Pubkeyfee_recipient_quote_token_account: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for PumpSwapBuyEvent
impl BorshDeserialize for PumpSwapBuyEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for PumpSwapBuyEvent
impl Clone for PumpSwapBuyEvent
Sourcefn clone(&self) -> PumpSwapBuyEvent
fn clone(&self) -> PumpSwapBuyEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PumpSwapBuyEvent
impl Debug for PumpSwapBuyEvent
Sourceimpl Default for PumpSwapBuyEvent
impl Default for PumpSwapBuyEvent
Sourcefn default() -> PumpSwapBuyEvent
fn default() -> PumpSwapBuyEvent
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PumpSwapBuyEvent
impl<'de> Deserialize<'de> for PumpSwapBuyEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more