pub struct RaydiumAmmV4SwapEvent {Show 23 fields
pub metadata: EventMetadata,
pub amm: Pubkey,
pub amount_in: u64,
pub amount_out: u64,
pub minimum_amount_out: u64,
pub max_amount_in: u64,
pub token_program: Pubkey,
pub amm_authority: Pubkey,
pub amm_open_orders: Pubkey,
pub amm_target_orders: Option<Pubkey>,
pub pool_coin_token_account: Pubkey,
pub pool_pc_token_account: Pubkey,
pub serum_program: Pubkey,
pub serum_market: Pubkey,
pub serum_bids: Pubkey,
pub serum_asks: Pubkey,
pub serum_event_queue: Pubkey,
pub serum_coin_vault_account: Pubkey,
pub serum_pc_vault_account: Pubkey,
pub serum_vault_signer: Pubkey,
pub user_source_token_account: Pubkey,
pub user_destination_token_account: Pubkey,
pub user_source_owner: Pubkey,
}Expand description
Raydium AMM V4 Swap Event
Fields
metadata: EventMetadataamm: Pubkeyamount_in: u64amount_out: u64minimum_amount_out: u64max_amount_in: u64token_program: Pubkeyamm_open_orders: Pubkeyamm_target_orders: Option<Pubkey>pool_coin_token_account: Pubkeypool_pc_token_account: Pubkeyserum_program: Pubkeyserum_market: Pubkeyserum_bids: Pubkeyserum_asks: Pubkeyserum_event_queue: Pubkeyserum_coin_vault_account: Pubkeyserum_pc_vault_account: Pubkeyserum_vault_signer: Pubkeyuser_source_token_account: Pubkeyuser_destination_token_account: Pubkeyuser_source_owner: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for RaydiumAmmV4SwapEvent
impl BorshDeserialize for RaydiumAmmV4SwapEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumAmmV4SwapEvent
impl Clone for RaydiumAmmV4SwapEvent
Sourcefn clone(&self) -> RaydiumAmmV4SwapEvent
fn clone(&self) -> RaydiumAmmV4SwapEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RaydiumAmmV4SwapEvent
impl Debug for RaydiumAmmV4SwapEvent
Sourceimpl<'de> Deserialize<'de> for RaydiumAmmV4SwapEvent
impl<'de> Deserialize<'de> for RaydiumAmmV4SwapEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more