pub struct RaydiumAmmV4WithdrawEvent {Show 24 fields
pub metadata: EventMetadata,
pub amm: Pubkey,
pub amount: u64,
pub token_program: Pubkey,
pub amm_authority: Pubkey,
pub amm_open_orders: Pubkey,
pub amm_target_orders: Pubkey,
pub lp_mint_address: Pubkey,
pub pool_coin_token_account: Pubkey,
pub pool_pc_token_account: Pubkey,
pub pool_withdraw_queue: Pubkey,
pub pool_temp_lp_token_account: Pubkey,
pub serum_program: Pubkey,
pub serum_market: Pubkey,
pub serum_coin_vault_account: Pubkey,
pub serum_pc_vault_account: Pubkey,
pub serum_vault_signer: Pubkey,
pub user_lp_token_account: Pubkey,
pub user_coin_token_account: Pubkey,
pub user_pc_token_account: Pubkey,
pub user_owner: Pubkey,
pub serum_event_queue: Pubkey,
pub serum_bids: Pubkey,
pub serum_asks: Pubkey,
}Expand description
Raydium AMM V4 Withdraw Event
Fields
metadata: EventMetadataamm: Pubkeyamount: u64token_program: Pubkeyamm_open_orders: Pubkeyamm_target_orders: Pubkeylp_mint_address: Pubkeypool_coin_token_account: Pubkeypool_pc_token_account: Pubkeypool_withdraw_queue: Pubkeypool_temp_lp_token_account: Pubkeyserum_program: Pubkeyserum_market: Pubkeyserum_coin_vault_account: Pubkeyserum_pc_vault_account: Pubkeyserum_vault_signer: Pubkeyuser_lp_token_account: Pubkeyuser_coin_token_account: Pubkeyuser_pc_token_account: Pubkeyuser_owner: Pubkeyserum_event_queue: Pubkeyserum_bids: Pubkeyserum_asks: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for RaydiumAmmV4WithdrawEvent
impl BorshDeserialize for RaydiumAmmV4WithdrawEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumAmmV4WithdrawEvent
impl Clone for RaydiumAmmV4WithdrawEvent
Sourcefn clone(&self) -> RaydiumAmmV4WithdrawEvent
fn clone(&self) -> RaydiumAmmV4WithdrawEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RaydiumAmmV4WithdrawEvent
impl Debug for RaydiumAmmV4WithdrawEvent
Sourceimpl<'de> Deserialize<'de> for RaydiumAmmV4WithdrawEvent
impl<'de> Deserialize<'de> for RaydiumAmmV4WithdrawEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more