pub struct RaydiumClmmCreatePersonalPositionEvent {
pub metadata: EventMetadata,
pub pool_state: Pubkey,
pub minter: Pubkey,
pub nft_owner: Pubkey,
pub tick_lower_index: i32,
pub tick_upper_index: i32,
pub liquidity: u128,
pub deposit_amount_0: u64,
pub deposit_amount_1: u64,
pub deposit_amount_0_transfer_fee: u64,
pub deposit_amount_1_transfer_fee: u64,
}Expand description
Raydium CLMM Create Personal Position Event (IDL CreatePersonalPositionEvent)
Fields
metadata: EventMetadatapool_state: Pubkeyminter: Pubkeynft_owner: Pubkeytick_lower_index: i32tick_upper_index: i32liquidity: u128deposit_amount_0: u64deposit_amount_1: u64deposit_amount_0_transfer_fee: u64deposit_amount_1_transfer_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for RaydiumClmmCreatePersonalPositionEvent
impl BorshDeserialize for RaydiumClmmCreatePersonalPositionEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumClmmCreatePersonalPositionEvent
impl Clone for RaydiumClmmCreatePersonalPositionEvent
Sourcefn clone(&self) -> RaydiumClmmCreatePersonalPositionEvent
fn clone(&self) -> RaydiumClmmCreatePersonalPositionEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RaydiumClmmCreatePersonalPositionEvent
impl<'de> Deserialize<'de> for RaydiumClmmCreatePersonalPositionEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more