pub struct RaydiumClmmDecreaseLimitOrderEvent {
pub metadata: EventMetadata,
pub pool_id: Pubkey,
pub limit_order: Pubkey,
pub zero_for_one: bool,
pub tick_index: i32,
pub total_amount: u64,
pub filled_amount: u64,
pub settled_output_amount: u64,
pub decreased_amount: u64,
}Expand description
Raydium CLMM Decrease Limit Order Event (IDL DecreaseLimitOrderEvent)
Fields
metadata: EventMetadatapool_id: Pubkeylimit_order: Pubkeyzero_for_one: booltick_index: i32total_amount: u64filled_amount: u64settled_output_amount: u64decreased_amount: u64Trait Implementations
Sourceimpl BorshDeserialize for RaydiumClmmDecreaseLimitOrderEvent
impl BorshDeserialize for RaydiumClmmDecreaseLimitOrderEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumClmmDecreaseLimitOrderEvent
impl Clone for RaydiumClmmDecreaseLimitOrderEvent
Sourcefn clone(&self) -> RaydiumClmmDecreaseLimitOrderEvent
fn clone(&self) -> RaydiumClmmDecreaseLimitOrderEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RaydiumClmmDecreaseLimitOrderEvent
impl<'de> Deserialize<'de> for RaydiumClmmDecreaseLimitOrderEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more