pub struct RaydiumClmmIncreaseLimitOrderEvent {
pub metadata: EventMetadata,
pub pool_id: Pubkey,
pub limit_order: Pubkey,
pub zero_for_one: bool,
pub tick_index: i32,
pub total_amount: u64,
pub increased_amount: u64,
pub transfer_fee: u64,
}Expand description
Raydium CLMM Increase Limit Order Event (IDL IncreaseLimitOrderEvent)
Fields
metadata: EventMetadatapool_id: Pubkeylimit_order: Pubkeyzero_for_one: booltick_index: i32total_amount: u64increased_amount: u64transfer_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for RaydiumClmmIncreaseLimitOrderEvent
impl BorshDeserialize for RaydiumClmmIncreaseLimitOrderEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumClmmIncreaseLimitOrderEvent
impl Clone for RaydiumClmmIncreaseLimitOrderEvent
Sourcefn clone(&self) -> RaydiumClmmIncreaseLimitOrderEvent
fn clone(&self) -> RaydiumClmmIncreaseLimitOrderEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RaydiumClmmIncreaseLimitOrderEvent
impl<'de> Deserialize<'de> for RaydiumClmmIncreaseLimitOrderEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more