pub struct RaydiumClmmLiquidityCalculateEvent {
pub metadata: EventMetadata,
pub pool_liquidity: u128,
pub pool_sqrt_price_x64: u128,
pub pool_tick: i32,
pub calc_amount_0: u64,
pub calc_amount_1: u64,
pub trade_fee_owed_0: u64,
pub trade_fee_owed_1: u64,
pub transfer_fee_0: u64,
pub transfer_fee_1: u64,
}Expand description
Raydium CLMM Liquidity Calculate Event (IDL LiquidityCalculateEvent)
Fields
metadata: EventMetadatapool_liquidity: u128pool_sqrt_price_x64: u128pool_tick: i32calc_amount_0: u64calc_amount_1: u64trade_fee_owed_0: u64trade_fee_owed_1: u64transfer_fee_0: u64transfer_fee_1: u64Trait Implementations
Sourceimpl BorshDeserialize for RaydiumClmmLiquidityCalculateEvent
impl BorshDeserialize for RaydiumClmmLiquidityCalculateEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumClmmLiquidityCalculateEvent
impl Clone for RaydiumClmmLiquidityCalculateEvent
Sourcefn clone(&self) -> RaydiumClmmLiquidityCalculateEvent
fn clone(&self) -> RaydiumClmmLiquidityCalculateEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RaydiumClmmLiquidityCalculateEvent
impl<'de> Deserialize<'de> for RaydiumClmmLiquidityCalculateEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more