pub struct RaydiumClmmUpdateRewardInfosEvent {
pub metadata: EventMetadata,
pub reward_growth_global_x64: [u128; 3],
}Expand description
Raydium CLMM Update Reward Infos Event (IDL UpdateRewardInfosEvent)
Fields
metadata: EventMetadatareward_growth_global_x64: [u128; 3]Trait Implementations
Sourceimpl BorshDeserialize for RaydiumClmmUpdateRewardInfosEvent
impl BorshDeserialize for RaydiumClmmUpdateRewardInfosEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumClmmUpdateRewardInfosEvent
impl Clone for RaydiumClmmUpdateRewardInfosEvent
Sourcefn clone(&self) -> RaydiumClmmUpdateRewardInfosEvent
fn clone(&self) -> RaydiumClmmUpdateRewardInfosEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RaydiumClmmUpdateRewardInfosEvent
impl<'de> Deserialize<'de> for RaydiumClmmUpdateRewardInfosEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more