pub struct RaydiumClmmDecreaseLiquidityEvent {Show 14 fields
pub metadata: EventMetadata,
pub position_nft_mint: Pubkey,
pub liquidity: u128,
pub decrease_amount_0: u64,
pub decrease_amount_1: u64,
pub fee_amount_0: u64,
pub fee_amount_1: u64,
pub reward_amounts: [u64; 3],
pub transfer_fee_0: u64,
pub transfer_fee_1: u64,
pub pool: Pubkey,
pub amount0_min: u64,
pub amount1_min: u64,
pub user: Pubkey,
}Expand description
Raydium CLMM Decrease Liquidity Event (IDL DecreaseLiquidityEvent)
Fields
metadata: EventMetadataposition_nft_mint: Pubkeyliquidity: u128decrease_amount_0: u64decrease_amount_1: u64fee_amount_0: u64fee_amount_1: u64reward_amounts: [u64; 3]transfer_fee_0: u64transfer_fee_1: u64pool: Pubkeyamount0_min: u64amount1_min: u64user: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for RaydiumClmmDecreaseLiquidityEvent
impl BorshDeserialize for RaydiumClmmDecreaseLiquidityEvent
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RaydiumClmmDecreaseLiquidityEvent
impl Clone for RaydiumClmmDecreaseLiquidityEvent
Sourcefn clone(&self) -> RaydiumClmmDecreaseLiquidityEvent
fn clone(&self) -> RaydiumClmmDecreaseLiquidityEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for RaydiumClmmDecreaseLiquidityEvent
impl<'de> Deserialize<'de> for RaydiumClmmDecreaseLiquidityEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more