#[repr(C)]pub struct AccountMeta {
pub pubkey: Address,
pub is_signer: bool,
pub is_writable: bool,
}Expand description
Describes a single account read or written by a program during instruction execution.
When constructing an Instruction, a list of all accounts that may be
read or written during the execution of that instruction must be supplied.
Any account that may be mutated by the program during execution, either its
data or metadata such as held lamports, must be writable.
Note that because the Solana runtime schedules parallel transaction
execution around which accounts are writable, care should be taken that only
accounts which actually may be mutated are specified as writable. As the
default AccountMeta::new constructor creates writable accounts, this is
a minor hazard: use AccountMeta::new_readonly to specify that an account
is not writable.
Fields
pubkey: AddressAn account’s public key.
is_signer: boolTrue if an Instruction requires a Transaction signature matching pubkey.
is_writable: boolTrue if the account data or metadata may be mutated during program execution.
Implementations
Sourceimpl AccountMeta
impl AccountMeta
Sourcepub fn new(pubkey: Address, is_signer: bool) -> AccountMeta
pub fn new(pubkey: Address, is_signer: bool) -> AccountMeta
Construct metadata for a writable account.
Examples
let instr = Instruction::new_with_borsh(
program_id,
&instruction,
vec![
AccountMeta::new(from, true),
AccountMeta::new(to, false),
],
);Sourcepub fn new_readonly(pubkey: Address, is_signer: bool) -> AccountMeta
pub fn new_readonly(pubkey: Address, is_signer: bool) -> AccountMeta
Construct metadata for a read-only account.
Examples
let instr = Instruction::new_with_borsh(
program_id,
&instruction,
vec![
AccountMeta::new(from, true),
AccountMeta::new(to, false),
AccountMeta::new_readonly(from_account_storage, false),
],
);Trait Implementations
Sourceimpl Clone for AccountMeta
impl Clone for AccountMeta
Sourcefn clone(&self) -> AccountMeta
fn clone(&self) -> AccountMeta
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AccountMeta
impl Debug for AccountMeta
Sourceimpl Default for AccountMeta
impl Default for AccountMeta
Sourcefn default() -> AccountMeta
fn default() -> AccountMeta
Sourceimpl<'de> Deserialize<'de> for AccountMeta
impl<'de> Deserialize<'de> for AccountMeta
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<AccountMeta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<AccountMeta, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl Eq for AccountMeta
Sourceimpl PartialEq for AccountMeta
impl PartialEq for AccountMeta
Sourceimpl<'de, __WincodeConfig> SchemaRead<'de, __WincodeConfig> for AccountMetawhere
__WincodeConfig: Config,
impl<'de, __WincodeConfig> SchemaRead<'de, __WincodeConfig> for AccountMetawhere
__WincodeConfig: Config,
type Dst = AccountMeta
Sourcefn read(
reader: impl Reader<'de>,
dst: &mut MaybeUninit<<AccountMeta as SchemaRead<'de, __WincodeConfig>>::Dst>,
) -> Result<(), ReadError>
fn read( reader: impl Reader<'de>, dst: &mut MaybeUninit<<AccountMeta as SchemaRead<'de, __WincodeConfig>>::Dst>, ) -> Result<(), ReadError>
Sourceimpl<__WincodeConfig> SchemaWrite<__WincodeConfig> for AccountMetawhere
__WincodeConfig: Config,
impl<__WincodeConfig> SchemaWrite<__WincodeConfig> for AccountMetawhere
__WincodeConfig: Config,
type Src = AccountMeta
Sourcefn size_of(
src: &<AccountMeta as SchemaWrite<__WincodeConfig>>::Src,
) -> Result<usize, WriteError>
fn size_of( src: &<AccountMeta as SchemaWrite<__WincodeConfig>>::Src, ) -> Result<usize, WriteError>
Self::Src. Read moreSourcefn write(
writer: impl Writer,
src: &<AccountMeta as SchemaWrite<__WincodeConfig>>::Src,
) -> Result<(), WriteError>
fn write( writer: impl Writer, src: &<AccountMeta as SchemaWrite<__WincodeConfig>>::Src, ) -> Result<(), WriteError>
Self::Src to writer.Sourceimpl Serialize for AccountMeta
impl Serialize for AccountMeta
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl StructuralPartialEq for AccountMeta
Sourceimpl TryFrom<&ExtraAccountMeta> for AccountMeta
impl TryFrom<&ExtraAccountMeta> for AccountMeta
Sourcetype Error = ProgramError
type Error = ProgramError
Sourcefn try_from(
pod: &ExtraAccountMeta,
) -> Result<AccountMeta, <AccountMeta as TryFrom<&ExtraAccountMeta>>::Error>
fn try_from( pod: &ExtraAccountMeta, ) -> Result<AccountMeta, <AccountMeta as TryFrom<&ExtraAccountMeta>>::Error>
Sourceimpl<__WincodeConfig> ZeroCopy<__WincodeConfig> for AccountMetawhere
__WincodeConfig: Config,
Address: for<'_wincode_internal> ZeroCopy<__WincodeConfig>,
bool: for<'_wincode_internal> ZeroCopy<__WincodeConfig> + for<'_wincode_internal> ZeroCopy<__WincodeConfig>,
__WincodeAssert<solana_instruction::::account_meta::_#2::{impl#1}::{constant#0}>: for<'_wincode_internal> __WincodeIsTrue,
impl<__WincodeConfig> ZeroCopy<__WincodeConfig> for AccountMetawhere
__WincodeConfig: Config,
Address: for<'_wincode_internal> ZeroCopy<__WincodeConfig>,
bool: for<'_wincode_internal> ZeroCopy<__WincodeConfig> + for<'_wincode_internal> ZeroCopy<__WincodeConfig>,
__WincodeAssert<solana_instruction::::account_meta::_#2::{impl#1}::{constant#0}>: for<'_wincode_internal> __WincodeIsTrue,
Sourcefn from_bytes<'de>(bytes: &'de [u8], config: C) -> Result<&'de Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
fn from_bytes<'de>(bytes: &'de [u8], config: C) -> Result<&'de Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
crate::ZeroCopy::from_bytes, but allows the caller to provide a custom configuration.Sourcefn from_bytes_mut<'de>(
bytes: &'de mut [u8],
config: C,
) -> Result<&'de mut Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
fn from_bytes_mut<'de>(
bytes: &'de mut [u8],
config: C,
) -> Result<&'de mut Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
crate::ZeroCopy::from_bytes_mut, but allows the caller to provide a custom configuration.Auto Trait Implementations
impl Freeze for AccountMeta
impl RefUnwindSafe for AccountMeta
impl Send for AccountMeta
impl Sync for AccountMeta
impl Unpin for AccountMeta
impl UnsafeUnpin for AccountMeta
impl UnwindSafe for AccountMeta